@@ -29,11 +29,14 @@ class InfluxDBClinet(object):
                 self._connected = False
         return self._connected
 
-    def query(self, sql_str):
+    def query(self, sql_str, params=None, bind_params=None, epoch=None):
         while not self._connect():
             sleep(0.1)
         items = []
-        for item in self._influx_client.query(query=sql_str):
+        for item in self._influx_client.query(query=sql_str, 
+                                            params=None,
+                                            bind_params=None,
+                                            epoch=None):
             items.append(item)
         if len(items):
             return items[0]
